==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/mbas/AssemblyInfo.cs <==
// MonoBASIC Compiler, this is a compiler for the MonoBASIC language, which is a superset of Visual Basic.NET
// Copyright (C) 2002  Rafael Teixeira
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//

using System.Reflection;
using System.Runtime.CompilerServices;

[assembly: AssemblyTitle("MonoBASIC Compiler")]
[assembly: AssemblyDescription("This is a compiler for the MonoBASIC language, \nwhich is a superset of Visual Basic.NET")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("")]
[assembly: AssemblyProduct("")]
[assembly: AssemblyCopyright("(c)2002, 2003, 2004, 2005 Rafael Teixeira")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]		

[assembly: Mono.Author("Sudharsan V")]
[assembly: Mono.Author("Satya Sudha K")]
[assembly: Mono.Author("Manjula GHM")]
[assembly: Mono.Author("Anirban Bhattacharjee")]
[assembly: Mono.Author("Martin Baulig")]
[assembly: Mono.Author("Marco Ridoni")]
[assembly: Mono.Author("Rafael Teixeira")]
[assembly: Mono.Author("Miguel de Icaza")]
[assembly: Mono.Author("Ravi Pratap")]

[assembly: Mono.About("Distributed under the GPL 2.0")]

[assembly: Mono.UsageComplement("SOURCE-FILES")]

//[assembly: Mono.LicensingWith(Mono.GetOptions.Licenses.GPL)]
[assembly: Mono.AdditionalInfo("For more information: http://www.mono-project.com/Language_BASIC")]
[assembly: Mono.ReportBugsTo(" http://bugzilla.ximian.com/enter_bug.cgi?product=Mono%3A+Compilers&component=Basic ")]

[assembly: AssemblyVersion("0.96.2.0")]

[assembly: AssemblyDelaySign(false)]
[assembly: AssemblyKeyFile("")]
[assembly: AssemblyKeyName("")]

==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/mbas/AssemblyInfo.cs <==
// MonoBASIC Compiler, this is a compiler for the MonoBASIC language, which is a superset of Visual Basic.NET
// Copyright (C) 2002  Rafael Teixeira
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//

using System.Reflection;
using System.Runtime.CompilerServices;

[assembly: AssemblyTitle("MonoBASIC Compiler")]
[assembly: AssemblyDescription("This is a compiler for the MonoBASIC language, \nwhich is a superset of Visual Basic.NET")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("")]
[assembly: AssemblyProduct("")]
[assembly: AssemblyCopyright("(c)2002, 2003, 2004, 2005 Rafael Teixeira")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]		

[assembly: Mono.Author("Sudharsan V")]
[assembly: Mono.Author("Satya Sudha K")]
[assembly: Mono.Author("Manjula GHM")]
[assembly: Mono.Author("Anirban Bhattacharjee")]
[assembly: Mono.Author("Martin Baulig")]
[assembly: Mono.Author("Marco Ridoni")]
[assembly: Mono.Author("Rafael Teixeira")]
[assembly: Mono.Author("Miguel de Icaza")]
[assembly: Mono.Author("Ravi Pratap")]

[assembly: Mono.About("Distributed under the GPL 2.0")]

[assembly: Mono.UsageComplement("SOURCE-FILES")]

//[assembly: Mono.LicensingWith(Mono.GetOptions.Licenses.GPL)]
[assembly: Mono.AdditionalInfo("For more information: http://www.mono-project.com/Language_BASIC")]
[assembly: Mono.ReportBugsTo(" http://bugzilla.ximian.com/enter_bug.cgi?product=Mono%3A+Compilers&component=Basic ")]

[assembly: AssemblyVersion(Consts.MonoVersion)]

[assembly: AssemblyDelaySign(false)]
[assembly: AssemblyKeyFile("")]
[assembly: AssemblyKeyName("")]
